==> haskell-lens-aeson-1.1.3-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lens-aeson
version:              1.1.3
visibility:           public
id:                   lens-aeson-1.1.3-HfhokWOG66y2zV6IXuzMaG
key:                  lens-aeson-1.1.3-HfhokWOG66y2zV6IXuzMaG
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson
    Copyright (C) 2013 Edward A. Kmett

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/lens/lens-aeson/
synopsis:             Law-abiding lenses for aeson
description:          Law-abiding lenses for aeson.
category:             Numeric
abi:                  51f86fecf0083d975435b494fd958e3a
exposed:              True
exposed-modules:      Data.Aeson.Lens
import-dirs:          /usr/lib/ghc-9.0.2/site-local/lens-aeson-1.1.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/lens-aeson-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-aeson
hs-libraries:         HSlens-aeson-1.1.3-HfhokWOG66y2zV6IXuzMaG
depends:
    aeson-1.5.6.0-ByG4maisB6W4LqbYiVYaDZ
    attoparsec-0.14.4-9zevo7QnectA1bRgJqQjSQ base-4.15.1.0
    bytestring-0.10.12.1 lens-5.1.1-4M5zSd24oOB3ODyeRSY1iF
    scientific-0.3.7.0-6FG4AfXYc7O3A3I5XDuAKY text-1.2.5.0
    unordered-containers-0.2.19.1-Egpruffujfv1ZeuVmASDK2
    vector-0.12.3.1-6Jse5cnDdy2CJPq6wEcUm1

haddock-interfaces:   /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html:         /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-aeson-1.1.3-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lens-aeson
version:              1.1.3
visibility:           public
id:                   lens-aeson-1.1.3-3VFNrWxIqWaFIQ9ze2NcGd
key:                  lens-aeson-1.1.3-3VFNrWxIqWaFIQ9ze2NcGd
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson
    Copyright (C) 2013 Edward A. Kmett

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/lens/lens-aeson/
synopsis:             Law-abiding lenses for aeson
description:          Law-abiding lenses for aeson.
category:             Numeric
abi:                  6529cdb0409667fcf6339a414f89a21d
exposed:              True
exposed-modules:      Data.Aeson.Lens
import-dirs:          /usr/lib/ghc-9.0.2/site-local/lens-aeson-1.1.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/lens-aeson-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-aeson
hs-libraries:         HSlens-aeson-1.1.3-3VFNrWxIqWaFIQ9ze2NcGd
depends:
    aeson-1.5.6.0-AKViGrmijRVB0tE3IZiiOh
    attoparsec-0.14.4-Gj1vArEZdggJnxQ5I0nGMx base-4.15.1.0
    bytestring-0.10.12.1 lens-5.1.1-5PPvtF24NNgJOUeY91kG7T
    scientific-0.3.7.0-KYI5HiTASyWGKyiBTJ4XLr text-1.2.5.0
    unordered-containers-0.2.19.1-DzqMNL8SmsvLUZuXVD6UYJ
    vector-0.12.3.1-DWLcs41oUpGB6FR7Q3d3DL

haddock-interfaces:   /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html:         /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
